@@ -137,7 +137,8 @@ C INTERPOLATES THE ZI VALUES.  (FOR MD=1,2,3)
    81 CONTINUE
       RETURN
 C ERROR EXIT
-   90 WRITE (LUN,2090) MD0,NCP0,NDP0,NIP0
+   90 CONTINUE                                                          
+C     WRITE (LUN,2090) MD0,NCP0,NDP0,NIP0
       RETURN
 C FORMAT STATEMENT FOR ERROR MESSAGE
  2090 FORMAT(1X/41H ***   IMPROPER INPUT PARAMETER VALUE(S)./
